@@ -7,7 +7,7 @@ use base qw/DBIx::Class::Core/;
 
 __PACKAGE__->table('cd');
 
-__PACKAGE__->add_columns(qw/ cdid artist title/);
+__PACKAGE__->add_columns(qw/ cdid artist title year /);
 
 __PACKAGE__->set_primary_key('cdid');
 
